/**
 * Represents a device entity in the of Home Assistant's device registry .
 *
 * @property {string} id - Unique identifier of the device (generated by Home Assistant).
 * @property {string[]} config_entries - Config entries linked to this device.
 * @property {Record<string, (string | null)[]>} config_entries_subentries - Subentries for the config entries.
 * @property {[string, string][]} connections - Tuples of (connection_type, connection identifier).
 * @property {[string, string][]} identifiers - Set of (DOMAIN, identifier) tuples identifying the device.
 * @property {string | null} manufacturer - The manufacturer of the device.
 * @property {string | null} model - The model name of the device.
 * @property {string | null} model_id - The model identifier of the device.
 * @property {string | null} name - The name of the device.
 * @property {string[]} labels - Labels for the device.
 * @property {string | null} sw_version - The firmware version of the device.
 * @property {string | null} hw_version - The hardware version of the device.
 * @property {string | null} serial_number - The serial number of the device.
 * @property {string | null} via_device_id - Identifier of a device that routes messages to this device.
 * @property {string | null} area_id - The area which the device is placed in.
 * @property {string | null} name_by_user - User configured name of the device.
 * @property {string[] | null} entry_type - The type of entry (e.g., service).
 * @property {string | null} disabled_by - Indicates what disabled this entity.
 * @property {string | null} configuration_url - URL for configuring the device.
 * @property {string | null} primary_config_entry - Identifier of the primary config entry for the device.
 */
export interface DeviceRegistryEntry {
  id: string;
  config_entries: string[];
  config_entries_subentries: Record<string, (string | null)[]>;
  connections: [string, string][];
  identifiers: [string, string][];
  manufacturer: string | null;
  model: string | null;
  model_id: string | null;
  name: string | null;
  labels: string[];
  sw_version: string | null;
  hw_version: string | null;
  serial_number: string | null;
  via_device_id: string | null;
  area_id: string | null;
  name_by_user: string | null;
  entry_type: 'service' | null;
  disabled_by: 'user' | 'integration' | 'config_entry' | null;
  configuration_url: string | null;
  primary_config_entry: string | null;
}
